# Welcome to barycenter

|        |        |
|--------|--------|
| Package | [![Latest PyPI Version](https://img.shields.io/pypi/v/barycenter.svg)](https://pypi.org/project/barycenter/) [![Supported Python Versions](https://img.shields.io/pypi/pyversions/barycenter.svg)](https://pypi.org/project/barycenter/)  |
| Meta   | [![Code of Conduct](https://img.shields.io/badge/Contributor%20Covenant-v2.0%20adopted-ff69b4.svg)](CODE_OF_CONDUCT.md) |

*TODO: the above badges that indicate python version and package version will only work if your package is on PyPI.
If you don't plan to publish to PyPI, you can remove them.*

barycenter is a project that (describe what it does here).

## Get started

You can install this package into your preferred Python environment using pip:

```bash
$ pip install barycenter
```

TODO: Add a brief example of how to use the package to this section

To use barycenter in your code:

```python
>>> import barycenter
>>> barycenter.hello_world()
```

## Copyright

- Copyright © 2025 Matteo Bachetti.
- Free software distributed under the [MIT License](./LICENSE).
